Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(441)

Unified Diff: tools/trusted_cross_toolchains/trusted-toolchain-creator.armel.precise.sh

Issue 25041003: Update ARM trusted root image to include precise security updates. (Closed) Base URL: https://chromium.googlesource.com/native_client/src/native_client.git@master
Patch Set: Created 7 years, 3 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « tools/trusted_cross_toolchains/trusted-toolchain-creator.armel.lucid.sh ('k') | no next file » | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: tools/trusted_cross_toolchains/trusted-toolchain-creator.armel.precise.sh
diff --git a/tools/trusted_cross_toolchains/trusted-toolchain-creator.armel.precise.sh b/tools/trusted_cross_toolchains/trusted-toolchain-creator.armel.precise.sh
index 505509e9a8f7c15aa58ed6862a40c15257c94c56..99f221ff6f7e2b352f07e23905d940bf256e47ec 100755
--- a/tools/trusted_cross_toolchains/trusted-toolchain-creator.armel.precise.sh
+++ b/tools/trusted_cross_toolchains/trusted-toolchain-creator.armel.precise.sh
@@ -20,8 +20,7 @@
#@ tools/trusted_cross_toolchains/trusted-toolchain-creator.armel.precise.sh <mode> <args>*
#@ Available modes are shown below.
#@
#@
#@ This Toolchain was tested with Ubuntu Lucid
#@
#@ Usage of this TC:
#@ compile: arm-linux-gnueabi-gcc -march=armv7-a -isystem ${JAIL}/usr/include
@@ -61,6 +60,7 @@ readonly CROSS_ARM_TC_REPO=http://archive.ubuntu.com/ubuntu
readonly ARMEL_REPO=http://ports.ubuntu.com/ubuntu-ports
readonly PACKAGE_LIST="${ARMEL_REPO}/dists/precise/main/binary-armel/Packages.bz2"
+readonly PACKAGE_LIST2="${ARMEL_REPO}/dists/precise-security/main/binary-armel/Packages.bz2"
# Packages for the host system
# NOTE: at one point we should get rid of the 4.5 packages
@@ -530,7 +530,7 @@ GeneratePackageList() {
/bin/rm -f ${output_file}
shift
for pkg in $@ ; do
- local pkg_full=$(grep -A 1 "${pkg}\$" ${TMP}/Packages | egrep -o "pool/.*")
+ local pkg_full=$(grep -A 1 "${pkg}\$" ${TMP}/Packages | tail -1 | egrep -o "pool/.*")
if [[ -z ${pkg_full} ]]; then
echo "ERROR: missing package: $pkg"
exit 1
@@ -549,8 +549,10 @@ GeneratePackageList() {
#@
UpdatePackageLists() {
local package_list="${TMP}/Packages.precise.bz2"
+ local package_list2="${TMP}/Packages.precise-security.bz2"
DownloadOrCopy ${PACKAGE_LIST} ${package_list}
- bzcat ${package_list} | egrep '^(Package:|Filename:)' > ${TMP}/Packages
+ DownloadOrCopy ${PACKAGE_LIST2} ${package_list2}
+ bzcat ${package_list} ${package_list2} | egrep '^(Package:|Filename:)' > ${TMP}/Packages
GeneratePackageList ${ARMEL_BASE_DEP_LIST} "${ARMEL_BASE_PACKAGES}"
GeneratePackageList ${ARMEL_EXTRA_DEP_LIST} "${ARMEL_EXTRA_PACKAGES}"
« no previous file with comments | « tools/trusted_cross_toolchains/trusted-toolchain-creator.armel.lucid.sh ('k') | no next file » | no next file with comments »
@@ -20,8 +20,7 @@
#@ Available modes are shown below.
#@
-#@
-#@ This Toolchain was tested with Ubuntu Lucid
+#@ This Toolchain was tested with Ubuntu Precise
#@
#@ Usage of this TC:

Powered by Google App Engine
This is Rietveld 408576698